"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const scripts_1 = require("@digest/scripts");
const angular = scripts_1.config.angular && scripts_1.config.babelAngular;
const emotion = scripts_1.config.emotion && scripts_1.config.babelEmotion;
const flow = scripts_1.config.flow && scripts_1.config.babelFlow;
const graphql = scripts_1.config.graphql && scripts_1.config.babelGraphQL;
const react = scripts_1.config.react && scripts_1.config.babelReact;
const reactNative = react && scripts_1.config.reactNative && scripts_1.config.babelReactNative;
const reactNativeWeb = reactNative && scripts_1.config.reactNativeWeb;
const typescript = scripts_1.config.typescript && scripts_1.config.babelTypeScript;
const babelConfig = function (api) {
    if (api) {
        api.cache.forever();
    }
    const plugins = [
        [
            '@babel/plugin-proposal-function-bind'
        ],
        [
            '@babel/plugin-proposal-export-default-from'
        ],
        [
            '@babel/plugin-proposal-logical-assignment-operators'
        ],
        [
            '@babel/plugin-proposal-optional-chaining',
            {
                loose: false
            }
        ],
        [
            '@babel/plugin-proposal-pipeline-operator',
            {
                proposal: 'minimal'
            }
        ],
        [
            '@babel/plugin-proposal-nullish-coalescing-operator',
            {
                loose: false
            }
        ],
        [
            '@babel/plugin-proposal-do-expressions'
        ],
        [
            '@babel/plugin-proposal-function-sent'
        ],
        [
            '@babel/plugin-proposal-export-namespace-from'
        ],
        [
            '@babel/plugin-proposal-numeric-separator'
        ],
        [
            '@babel/plugin-proposal-throw-expressions'
        ],
        [
            '@babel/plugin-syntax-import-meta'
        ]
    ].concat(typescript ?
        [
            [
                '@babel/plugin-transform-typescript'
            ]
        ] :
        [], [
        [
            '@babel/plugin-proposal-class-properties',
            {
                loose: false
            }
        ],
        [
            '@babel/plugin-proposal-decorators',
            {
                legacy: true
            }
        ]
    ], scripts_1.config.webpackBabel ?
        [
            [
                '@babel/plugin-syntax-dynamic-import'
            ]
        ] :
        [
            [
                'babel-plugin-dynamic-import-node-babel-7'
            ]
        ], scripts_1.production ?
        [
            [
                'babel-plugin-transform-node-env-inline'
            ]
        ] :
        [], emotion ?
        [
            [
                '@emotion'
            ]
        ] :
        [], react ?
        [
            [
                '@babel/plugin-transform-react-display-name'
            ]
        ] :
        [], reactNativeWeb ?
        [
            [
                'module-resolver',
                {
                    alias: {
                        '^react-native$': 'react-native-web'
                    }
                }
            ],
            [
                'react-native-web'
            ]
        ] :
        [], angular ?
        [] :
        [], [
        [
            '@babel/plugin-transform-destructuring'
        ],
        [
            '@babel/plugin-transform-runtime',
            {
                helpers: false,
                regenerator: true
            }
        ],
        [
            '@babel/plugin-transform-regenerator',
            {
                async: false
            }
        ],
        [
            '@babel/plugin-transform-classes'
        ]
    ], scripts_1.config.cssModules &&
        react ?
        [
            [
                '@dr.pogodin/babel-plugin-react-css-modules',
                {
                    context: scripts_1.config.context,
                    generateScopedName: scripts_1.config.library ?
                        `${scripts_1.config.shortName}-[local]` :
                        `[local]-[hash:${scripts_1.config.hashLimit}]`
                }
            ]
        ] :
        [], scripts_1.production &&
        react &&
        !scripts_1.config.library ?
        [
            [
                '@babel/plugin-transform-react-inline-elements'
            ]
        ] :
        [], scripts_1.production &&
        react ?
        [
            [
                'babel-plugin-react-remove-properties',
                {
                    properties: [
                        'data-test',
                        'data-test-id',
                        'data-testid'
                    ]
                }
            ],
            [
                'babel-plugin-transform-react-remove-prop-types',
                {
                    removeImport: true
                }
            ],
            [
                '@babel/plugin-transform-react-constant-elements',
                {
                    allowMutablePropsOnTags: [
                        'FormattedMessage'
                    ]
                }
            ]
        ] :
        [], !scripts_1.production &&
        react &&
        scripts_1.config.webpackBabel ?
        [
            require.resolve('react-refresh/babel')
        ] :
        [], scripts_1.production &&
        graphql ?
        [
            [
                'babel-plugin-graphql-tag'
            ]
        ] :
        []);
    const presets = [].concat(scripts_1.config.babelPreset ?
        [
            [
                '@babel/preset-env',
                {
                    corejs: 3,
                    debug: false,
                    modules: false,
                    useBuiltIns: 'usage'
                }
            ]
        ] :
        [], react ?
        [
            [
                '@babel/preset-react',
                {
                    development: !scripts_1.production,
                    useBuiltIns: false
                }
            ]
        ] :
        [], typescript ?
        [
            [
                '@babel/preset-typescript',
                {}
            ]
        ] :
        [], flow ?
        [
            [
                '@babel/preset-flow',
                {}
            ]
        ] :
        []);
    return {
        plugins,
        presets
    };
};
module.exports = babelConfig;
